*****
PyJob
*****

**Python-controlled job execution across multiple platforms**

.. image:: https://img.shields.io/pypi/v/pyjob.svg
   :target: https://pypi.python.org/pypi/pyjob
   :alt: PyPi Package

.. image:: https://travis-ci.org/fsimkovic/pyjob.svg
   :target: https://travis-ci.org/fsimkovic/pyjob
   :alt: Travis-CI Build 

.. image:: https://ci.appveyor.com/api/projects/status/8ese0ymw0q2lbx3c/branch/master?svg=true
   :target: https://ci.appveyor.com/project/fsimkovic/pyjob
   :alt: AppVeyor Build

.. image:: https://codecov.io/gh/fsimkovic/pyjob/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/fsimkovic/pyjob
   :alt: Codecov Status

.. image:: https://img.shields.io/pypi/pyversions/pyjob.svg
   :target: https://pypi.python.org/pypi/pyjob
   :alt: Python Version

Installation
------------

**Latest official release**

.. code-block:: bash
   
   $ pip install pyjob

**Source code**

.. code-block:: bash
   
   $ git clone https://github.com/fsimkovic/pyjob.git
   $ cd pyjob
   $ python setup.py install

.. CHECKPOINT FOR READTHEDOCS 
For further details about PyJob, we'd suggest you head over to the `official documentation <http://pyjob.readthedocs.io/en/latest/>`_.
